@@ -596,8 +596,8 @@ class EventWaveformClient(BaseClient):
             "month": f"{month:02d}",
             "day": f"{day:02d}",
             "region": region,
-            "mags": magmin,
-            "mage": magmax,
+            "mags": str(f"{magmin:.1f}"),  # magnitude must be 3.0, not 3
+            "mage": str(f"{magmax:.1f}"),
             "undet": 0 if include_unknown_mag else 1,
             "sort": 0,  # always sort by origin time in ascending order
             "arc": "ZIP",  # meaningless arguement in this request
@@ -812,16 +812,23 @@ class EventWaveformClient(BaseClient):
             if not starttime <= event.origin <= endtime:
                 continue
             # select events based on magnitude
-            if not minmagnitude <= event.magnitude <= maxmagnitude:
+            if (event.magnitude != -99.9) and (
+                not minmagnitude <= event.magnitude <= maxmagnitude
+            ):
                 continue
             # select events based on depth
-            if mindepth and event.depth < mindepth:
+            if mindepth is not None and event.depth < mindepth:
                 continue
-            if maxdepth and event.depth > maxdepth:
+            if maxdepth is not None and event.depth > maxdepth:
                 continue
 
             # select events in a box region
-            if minlatitude or maxlatitude or minlongitude or maxlongitude:
+            if (
+                minlatitude is not None
+                or maxlatitude is not None
+                or minlongitude is not None
+                or maxlongitude is not None
+            ):
                 if not point_inside_box(
                     event.latitude,
                     event.longitude,
@@ -833,7 +840,9 @@ class EventWaveformClient(BaseClient):
                     continue
 
             # select events in a circular region
-            if (latitude and longitude) and (minradius or maxradius):
+            if (latitude is not None and longitude is not None) and (
+                minradius is not None or maxradius is not None
+            ):
                 if not point_inside_circular(
                     event.latitude,
                     event.longitude,
@@ -1355,7 +1364,10 @@ class Event:
             self.longitude = -float(longitude[:-1])
 
         self.depth = float(depth.strip("km"))
-        self.magnitude = float(magnitude)
+        if magnitude == "#":  # unknown magnitude
+            self.magnitude = -99.9
+        else:
+            self.magnitude = float(magnitude)
         self.name = name
         self.name_en = name_en
 
